<?xml version="1.0" encoding="UTF-8"?>

<!--
    地方海上予報 全内容出力スタイルシート
    ver1.0.0 2016年09月15日
    ver1.1.0 2019年04月24日  5月1日より施行される新元号への対応
-->

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:jmx="http://xml.kishou.go.jp/jmaxml1/"
    xmlns:h="http://xml.kishou.go.jp/jmaxml1/informationBasis1/"
    xmlns:b="http://xml.kishou.go.jp/jmaxml1/body/meteorology1/"
    xmlns:jmx_eb="http://xml.kishou.go.jp/jmaxml1/elementBasis1/">

    <xsl:output method="html" indent="no" encoding="Shift-JIS"/>

    <!-- メイン -->
    <xsl:template match="/">
        <html>
            <body>
                <xsl:apply-templates select="jmx:Report/jmx:Control"/>
                <xsl:apply-templates select="jmx:Report/h:Head"/>
                <xsl:apply-templates select="jmx:Report/b:Body/b:Warning"/>
                <xsl:apply-templates select="jmx:Report/b:Body/b:MeteorologicalInfos[@type = '気象要因']" mode="Yoin"/>
                <xsl:apply-templates select="jmx:Report/b:Body/b:MeteorologicalInfos[@type = '観測実況']" mode="Jikkyo"/>
                <xsl:apply-templates select="jmx:Report/b:Body/b:MeteorologicalInfos[@type = '地方海域の予報']/b:MeteorologicalInfo/b:Item" mode="Yoso"/>
            </body>
        </html>
    </xsl:template>

    <!-- Control部を出力 -->
    <xsl:template match="jmx:Control">
        <table border="1">
            <tr>
                <th>タイトル</th>
                <th>送信時刻</th>
                <th>通常／訓練／試験</th>
                <th>編集官署</th>
                <th>発表官署</th>
            </tr>
            <tr>
                <td><xsl:value-of select="jmx:Title"/></td>
                <td><xsl:value-of select="jmx:DateTime"/></td>
                <td><xsl:value-of select="jmx:Status"/></td>
                <td><xsl:value-of select="jmx:EditorialOffice"/></td>
                <td><xsl:value-of select="jmx:PublishingOffice"/></td>
            </tr>
        </table>
        <br/>
    </xsl:template>

    <!-- Head部を出力 -->
    <xsl:template match="h:Head">
        <table border="1">
            <tr>
                <th>タイトル</th>
                <th>発表時刻</th>
                <th>基点時刻</th>
                <th>対象期間</th>
                <th>発表／訂正</th>
            </tr>
            <tr>
                <td><xsl:value-of select="h:Title"/></td>
                <td><xsl:value-of select="h:ReportDateTime"/></td>
                <td><xsl:value-of select="h:TargetDateTime"/></td>
                <td><xsl:value-of select="h:TargetDuration"/></td>
                <td><xsl:value-of select="h:InfoType"/></td>
            </tr>
        </table>
        <br/>
    </xsl:template>

    <!-- 海上警報を出力 -->
    <xsl:template match="b:Warning">
        <p><xsl:value-of select="@type"/></p>
        <table border="1">
            <tr>
                <th>海域</th>
                <th>海上警報</th>
            </tr>
            <xsl:apply-templates select="b:Item" mode="Keiho"/>
        </table>
        <br/>
    </xsl:template>

    <!-- 海域と警報を出力 -->
    <xsl:template match="b:Item" mode="Keiho">
        <tr>
            <xsl:apply-templates select="b:Area"/>
            <td><xsl:apply-templates select="b:Kind" mode="Keiho"/></td>
        </tr>
    </xsl:template>

    <!-- 警報名とコードを出力（空白で区切る） -->
    <xsl:template match="b:Kind" mode="Keiho">
        <xsl:if test="position() > 1">
            <xsl:text>　</xsl:text>
        </xsl:if>
        <xsl:value-of select="b:Name"/>
        <xsl:if test="b:Code">
            <xsl:text>（</xsl:text>
            <xsl:value-of select="b:Code"/>
            <xsl:text>）</xsl:text>
        </xsl:if>
        <xsl:value-of select="b:Status"/>
    </xsl:template>

    <!-- 気象要因を出力 -->
    <xsl:template match="b:MeteorologicalInfos" mode="Yoin">
        <p><xsl:value-of select="@type"/></p>
        <table border="1">
            <tr>
                <th>観測日時</th>
                <th>海域</th>
                <th>気象要因</th>
            </tr>
            <xsl:apply-templates select="b:MeteorologicalInfo" mode="Yoin"/>
        </table>
        <br/>
    </xsl:template>

    <!-- 気象要因を出力 -->
    <xsl:template match="b:MeteorologicalInfo" mode="Yoin">
        <tr>
            <td><xsl:value-of select="b:Name"/></td>
            <xsl:apply-templates select="b:Item" mode="Yoin"/>
        </tr>
    </xsl:template>

    <!-- 気象要因を出力 -->
    <xsl:template match="b:Item" mode="Yoin">
        <xsl:apply-templates select="b:Area"/>
        <td><xsl:value-of select="b:Kind/b:Property/b:SynopsisPart/jmx_eb:Synopsis"/></td>
    </xsl:template>

    <!-- 海域名とコードを出力 -->
    <xsl:template match="b:Area">
        <td><xsl:apply-templates select="." mode="NameAndCode"/></td>
    </xsl:template>

    <!-- 観測実況を出力 -->
    <xsl:template match="b:MeteorologicalInfos" mode="Jikkyo">
        <p>
            <xsl:value-of select="@type"/>
            <xsl:text>　</xsl:text>
            <xsl:value-of select="b:MeteorologicalInfo/b:Name"/>
        </p>
        <table border="1">
            <tr>
                <th>観測地点</th>
                <th>通常／欠測あり／入電なし</th>
                <th>風向</th>
                <th>風速</th>
                <th>天気</th>
                <th>気圧</th>
                <th>気温</th>
                <th>視程</th>
            </tr>
            <xsl:apply-templates select="b:MeteorologicalInfo/b:Item" mode="Jikkyo"/>
        </table>
        <br/>
    </xsl:template>

    <!-- 観測地点と観測値を出力 -->
    <xsl:template match="b:Item" mode="Jikkyo">
        <tr>
            <xsl:apply-templates select="b:Station"/>
            <xsl:apply-templates select="b:Kind" mode="Jikkyo"/>
        </tr>
    </xsl:template>

    <!-- 観測地点を出力 -->
    <xsl:template match="b:Station">
        <td><xsl:apply-templates select="." mode="NameAndCode"/></td>
    </xsl:template>

    <!-- 観測値を出力 -->
    <xsl:template match="b:Kind" mode="Jikkyo">
        <td><xsl:value-of select="b:Condition"/></td>
        <td><xsl:apply-templates select="b:Property/b:WindDirectionPart/jmx_eb:WindDirection" mode="Jikkyo"/></td>
        <td><xsl:apply-templates select="b:Property/b:WindSpeedPart/jmx_eb:WindSpeed" mode="Jikkyo"/></td>
        <td><xsl:apply-templates select="b:Property/b:WeatherPart/jmx_eb:Weather" mode="Jikkyo"/></td>
        <td><xsl:apply-templates select="b:Property/b:PressurePart/jmx_eb:Pressure" mode="Jikkyo"/></td>
        <td><xsl:apply-templates select="b:Property/b:TemperaturePart/jmx_eb:Temperature" mode="Jikkyo"/></td>
        <td><xsl:apply-templates select="b:Property/b:VisibilityPart/jmx_eb:Visibility" mode="Jikkyo"/></td>
    </xsl:template>

    <!-- 風向／天気を出力 -->
    <xsl:template match="jmx_eb:WindDirection|jmx_eb:Weather" mode="Jikkyo">
        <xsl:value-of select="."/>
        <xsl:value-of select="@description"/>
    </xsl:template>

    <!-- 風速／気圧／気温／視程を出力 -->
    <xsl:template match="jmx_eb:WindSpeed|jmx_eb:Pressure|jmx_eb:Temperature|jmx_eb:Visibility" mode="Jikkyo">
        <xsl:value-of select="@description"/>
    </xsl:template>

    <!-- 海上予報を出力 -->
    <xsl:template match="b:Item" mode="Yoso">
        <p>
            <xsl:value-of select="../../@type"/>
            <xsl:text>　</xsl:text>
            <xsl:value-of select="../b:Name"/>
            <xsl:text>　</xsl:text>
            <xsl:apply-templates select="b:Area" mode="NameAndCode"/>
        </p>
        <table border="1">
            <tr>
                <th>要素</th>
                <th>（特定海域）</th>
                <th>予報平文</th>
                <th>予想時間</th>
                <th colspan="2">量的予想</th>
                <th>付加事項</th>
            </tr>
            <xsl:apply-templates select="b:Kind/b:Property/*/b:SubArea"/>
        </table>
        <br/>
    </xsl:template>

    <!-- 要素と海域と予報を出力 -->
    <xsl:template match="b:SubArea">
        <tr>
            <xsl:apply-templates select="." mode="Area"/>
            <xsl:apply-templates select="." mode="Sentence"/>
            <xsl:apply-templates select="b:Base"/>
            <xsl:apply-templates select="." mode="Remark"/>
        </tr>
        <xsl:apply-templates select="b:Becoming"/>
    </xsl:template>

    <!-- 要素と特定海域（ある場合のみ）を出力 -->
    <xsl:template match="b:SubArea" mode="Area">
        <xsl:choose>
        <xsl:when test="b:AreaName">
            <!-- 特定海域がある場合 -->
            <td>
                <xsl:attribute name="rowspan">
                    <xsl:value-of select="count(b:Becoming) + 1"/>
                </xsl:attribute>
                <xsl:value-of select="../../b:Type"/>
            </td>
            <td>
                <xsl:attribute name="rowspan">
                    <xsl:value-of select="count(b:Becoming) + 1"/>
                </xsl:attribute>
                <xsl:value-of select="b:AreaName"/>
            </td>
        </xsl:when>
        <xsl:otherwise>
            <!-- 特定海域がない場合 -->
            <td colspan="2">
                <xsl:attribute name="rowspan">
                    <xsl:value-of select="count(b:Becoming) + 1"/>
                </xsl:attribute>
                <xsl:value-of select="../../b:Type"/>
            </td>
        </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- 予報平文を出力 -->
    <xsl:template match="b:SubArea" mode="Sentence">
        <td>
            <xsl:attribute name="rowspan">
                <xsl:value-of select="count(b:Becoming) + 1"/>
            </xsl:attribute>
            <xsl:value-of select="b:Sentence"/>
        </td>
    </xsl:template>

    <!-- 付加事項を出力 -->
    <xsl:template match="b:SubArea" mode="Remark">
        <td>
            <xsl:attribute name="rowspan">
                <xsl:value-of select="count(b:Becoming) + 1"/>
            </xsl:attribute>
            <xsl:value-of select="b:Remark"/>
        </td>
    </xsl:template>

    <!-- 予想(Base)を出力 -->
    <xsl:template match="b:Base">
        <td>今後</td>
        <xsl:apply-templates select="." mode="Common"/>
    </xsl:template>

    <!-- 予想(Becoming)を出力 -->
    <xsl:template match="b:Becoming">
        <tr>
            <td><xsl:value-of select="b:TimeModifier"/></td>
            <xsl:apply-templates select="." mode="Common"/>
        </tr>
    </xsl:template>

    <!-- 量的予想を出力 -->
    <xsl:template match="b:Base|b:Becoming" mode="Common">
        <xsl:if test="../../../b:Type = '風'">
            <xsl:apply-templates select="." mode="Wind"/>
        </xsl:if>
        <xsl:if test="../../../b:Type = '天気'">
            <xsl:apply-templates select="." mode="Weather"/>
        </xsl:if>
        <xsl:if test="../../../b:Type = '視程'">
            <xsl:apply-templates select="." mode="Visibility"/>
        </xsl:if>
        <xsl:if test="../../../b:Type = '波'">
            <xsl:apply-templates select="." mode="WaveHeight"/>
        </xsl:if>
        <xsl:if test="../../../b:Type = '流氷'">
            <xsl:apply-templates select="." mode="SeaIce"/>
        </xsl:if>
    </xsl:template>

    <!-- 量的予想を出力（風用） -->
    <xsl:template match="b:Base|b:Becoming" mode="Wind">
        <td><xsl:apply-templates select="jmx_eb:WindDirection"/></td>
        <td>
            <xsl:apply-templates select="jmx_eb:WindSpeed[not(@unit = 'm/s')]"/>
            <xsl:if test="jmx_eb:WindSpeed[@unit = 'm/s']">
                <xsl:text>（</xsl:text>
                <xsl:apply-templates select="jmx_eb:WindSpeed[@unit = 'm/s']"/>
                <xsl:text>）</xsl:text>
            </xsl:if>
        </td>
    </xsl:template>

    <!-- 量的予想を出力（天気用） -->
    <xsl:template match="b:Base|b:Becoming" mode="Weather">
        <xsl:choose>
        <xsl:when test="b:Local">
            <!-- 所によりがある場合 -->
            <td><xsl:value-of select="jmx_eb:Weather"/></td>
            <td><xsl:value-of select="b:Local/b:Sentence"/></td>
        </xsl:when>
        <xsl:otherwise>
            <!-- 所によりがない場合 -->
            <td colspan="2"><xsl:value-of select="jmx_eb:Weather"/></td>
        </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- 量的予想を出力（視程用） -->
    <xsl:template match="b:Base|b:Becoming" mode="Visibility">
        <xsl:choose>
        <xsl:when test="b:Local">
            <!-- 所によりがある場合 -->
            <td><xsl:apply-templates select="." mode="VisibilityValue"/></td>
            <td>所により<xsl:apply-templates select="b:Local" mode="VisibilityValue"/></td>
        </xsl:when>
        <xsl:otherwise>
            <!-- 所によりがない場合 -->
            <td colspan="2"><xsl:apply-templates select="." mode="VisibilityValue"/></td>
        </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
            
    <!-- 量的予想を出力（視程用） -->
    <xsl:template match="b:Base|b:Becoming|b:Local" mode="VisibilityValue">
        <xsl:apply-templates select="jmx_eb:Visibility[not(@unit = 'km')]"/>
        <xsl:if test="jmx_eb:Visibility[@unit = 'km']">
            <xsl:text>（</xsl:text>
            <xsl:apply-templates select="jmx_eb:Visibility[@unit = 'km']"/>
            <xsl:text>）</xsl:text>
        </xsl:if>
    </xsl:template>

    <!-- 量的予想を出力（波高用） -->
    <xsl:template match="b:Base|b:Becoming" mode="WaveHeight">
        <td colspan="2"><xsl:value-of select="jmx_eb:WaveHeight/@description"/></td>
    </xsl:template>

    <!-- 量的予想を出力（流氷用） -->
    <xsl:template match="b:Base|b:Becoming" mode="SeaIce">
        <td colspan="2"><xsl:value-of select="jmx_eb:SeaIce/@description"/></td>
    </xsl:template>

    <!-- 風向を出力 -->
    <xsl:template match="jmx_eb:WindDirection">
        <xsl:if test="position() > 1">
            <xsl:text>又は</xsl:text>
        </xsl:if>
        <xsl:value-of select="."/>
    </xsl:template>

    <!-- 風速／視程を出力 -->
    <xsl:template match="jmx_eb:WindSpeed|jmx_eb:Visibility">
        <xsl:if test="position() > 1">
            <xsl:text>から</xsl:text>
        </xsl:if>
        <xsl:value-of select="@description"/>
    </xsl:template>

    <!-- 名称とコードを出力 -->
    <xsl:template match="b:Area|b:Station" mode="NameAndCode">
        <xsl:value-of select="b:Name"/>
        <xsl:text>（</xsl:text>
        <xsl:value-of select="b:Code"/>
        <xsl:text>）</xsl:text>
    </xsl:template>

</xsl:stylesheet>

